Catch2 Test Fixes (#2961)
* test fixes * address PR comment * PR comment fixing Nvidia pass * add additional kernel launch checks * pr comments
This commit is contained in:
@@ -49,7 +49,9 @@ TEST_CASE("Unit_hipMultiStream_sameDevice") {
|
||||
HIP_CHECK(hipStreamCreate(&streams[i]));
|
||||
HIP_CHECK(hipMalloc(&data[i], NN * sizeof(float)));
|
||||
hipLaunchKernelGGL(kernel, dim3(1), dim3(1), 0, streams[i], data[i], xd, NN);
|
||||
HIP_CHECK(hipGetLastError());
|
||||
hipLaunchKernelGGL(HIP_KERNEL_NAME(nKernel), dim3(1), dim3(1), 0, 0, yd);
|
||||
HIP_CHECK(hipGetLastError());
|
||||
HIP_CHECK(hipFree(data[i]));
|
||||
HIP_CHECK(hipStreamDestroy(streams[i]));
|
||||
}
|
||||
@@ -80,9 +82,11 @@ TEST_CASE("Unit_hipMultiStream_multimeDevice") {
|
||||
HIP_CHECK(hipDeviceSynchronize());
|
||||
// Launch kernel with default stream
|
||||
hipLaunchKernelGGL(kernel_do_nothing, dim3(1), dim3(1), 0, 0, 1);
|
||||
HIP_CHECK(hipGetLastError());
|
||||
// Launch kernel on all streams
|
||||
for (int i = 0; i < nStreams; i++) {
|
||||
hipLaunchKernelGGL(kernel_do_nothing, dim3(1), dim3(1), 0, streams[i], 1);
|
||||
HIP_CHECK(hipGetLastError());
|
||||
}
|
||||
// Sync stream 1
|
||||
HIP_CHECK(hipStreamSynchronize(streams[0]));
|
||||
|
||||
Reference in New Issue
Block a user